/*
   Name:    "ShowSize.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShowSize.rex"
                or
            "java com.ibm.bsf.Main            -in ShowSize.rex"

   Purpose:  create a little resizable window with a push button to reveal the actual
             size; adds EventListeners in order for Rexx to be notified, if a button
             is pressed or the Window closed (by pressing the System close button)

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-18

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

call BSF 'registerBean', 'Window', 'java.awt.Frame', 'String', 'Show size'
call BSF 'addEventListener', 'Window', 'window', 'windowClosing', 'call BSF "exit"'

call BSF 'registerBean', 'Button', 'java.awt.Button', 'String', 'Press me!'
call BSF 'addEventListener', 'Button', 'action', '', 'call ShowSize'

call BSF 'registerBean', 'Label', 'java.awt.Label'
call BSF 'invoke', 'Label', 'setAlignment', 'I', bsf('getFieldValue', 'Label', 'CENTER')

call BSF 'invoke', 'Window', 'add', 'String', 'Center', 'Object',  'Label'
call BSF 'invoke', 'Window', 'add', 'String', 'South',   'Object', 'Button'
call BSF 'invoke', 'Window', 'pack'
call BSF 'invoke', 'Window', 'setSize', 'int', 250, 'int', 150
call BSF 'invoke', 'Window', 'setLocation', 'int', 100, 'int', 100
call BSF 'invoke', 'Window', 'show'
call BSF 'invoke', 'Window', 'toFront'

secs=3
info="sleeping" secs  "seconds ..."
call BSF 'invoke', 'Label', 'setText', 'String', info
say info
call bsf 'sleep', secs  /* sleep i seconds using bsf4rexx       */

do i=100 to 300 by 10   /* animate the window a little bit      */
   call BSF 'invoke', 'Window', 'setLocation', 'int', i, 'int', (i/3)%1
   call BSF 'invoke', 'Window', 'setSize', 'int', (i*.9)%1, 'int', 100+i%3
   call BSF 'invoke', 'Window', 'show'
   call ShowSize
   call bsf 'sleep', .1         /* sleep i seconds using bsf4rexx       */
end

do forever
        /* a direct call always returns a string, in the
           case of a Java "null" by default the string ".NIL"   */
   a = bsf("pollEventText", 1000)       /* wait for an eventText to be sent,
                                           after 1 second return anyway         */

   if a=".NIL" then say "Rexx: no eventText so far ..."
   else
   do
      say "received the following eventText: ["a"]"
      interpret a               /* execute as a Rexx program    */
      if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown in 1/10sec      */
      say "Rexx: sleeping" secs "secs"
      call bsf 'sleep', secs    /* sleep i seconds using bsf4rexx       */
      say "Rexx: awakened!"
   end
end
exit


ShowSize: procedure

   dim   =bsf('invoke', 'Window', 'getSize')    /* get dimension object */
   string=bsf('invoke', dim, 'toString')        /* get String rendering */
   call BSF 'unregisterBean', dim               /* free Java registry   */

   parse var string "width=" width ",height=" height "]"
   call BSF 'invoke', 'Label', 'setText', 'String', "(" width "/" height ")"
   return




